Chapter Requesting and Scraping
===============================

Commands to request and save Chapters HTML files to the local disk, or to scrap its contents.
        
.. click:: web_novel_scraper.__main__:request_all_chapters
    :prog: request-all-chapters
    :nested: full
        
.. click:: web_novel_scraper.__main__:show_chapters
    :prog: show-chapters
    :nested: full
        
.. click:: web_novel_scraper.__main__:show_toc
    :prog: show-toc
    :nested: full
    